# AeroCaps
Toolkit for design of Class-A, parametric design of aerodynamic surfaces

## Installation

For installation of `aerocaps` using the latest stable release, open a terminal 
and use the following command:

```shell
pip install aerocaps
```

To install the bleeding-edge version instead, open a terminal 
and use the following command:

```shell
cd <Install-Parent-Location>
git clone https://github.com/mlau154/aerocaps.git
cd <Install-Parent-Location>/aerocaps
pip install .
```

## Updating

To update `aerocaps` to the newest version from the basic install, use

```shell
pip install aerocaps --upgrade
```

From the bleeding-edge version, use

```shell
cd <Install-Location>
git pull
pip install .
```
